@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -20,6 +20,7 @@
 
 #include "customdebugsettingspagetest.h"
 #include "../src/customdebugsettingspage.h"
+#include <KListWidgetSearchLine>
 #include <QLabel>
 #include <QListWidget>
 #include <QPushButton>
@@ -28,12 +29,10 @@
 CustomDebugSettingsPageTest::CustomDebugSettingsPageTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 CustomDebugSettingsPageTest::~CustomDebugSettingsPageTest()
 {
-
 }
 
 void CustomDebugSettingsPageTest::shouldHaveDefaultValue()
@@ -45,8 +44,14 @@ void CustomDebugSettingsPageTest::shouldHaveDefaultValue()
 
     QListWidget *listWidget = page.findChild<QListWidget *>(QStringLiteral("custom_listwidget"));
     QVERIFY(listWidget);
+    QCOMPARE(listWidget->selectionMode(), QAbstractItemView::MultiSelection);
     QCOMPARE(listWidget->count(), 0);
 
+    KListWidgetSearchLine *searchLine = page.findChild<KListWidgetSearchLine *>(QStringLiteral("searchline"));
+    QVERIFY(searchLine);
+    QVERIFY(!searchLine->placeholderText().isEmpty());
+    QCOMPARE(searchLine->listWidget(), listWidget);
+
     QPushButton *addButton = page.findChild<QPushButton *>(QStringLiteral("add_rule"));
     QVERIFY(addButton);
     QVERIFY(addButton->isEnabled());
